@@ -87,7 +87,7 @@ def execute_code_remotely_docker_sync(
                     f"sh -c '{linux_import}'", user="root"
                 )  # .exec_run(cmd)
                 if exit_code != 0:
-                    raise Exception(f"Linux import command failed: {linux_import}")
+                    raise Exception(f"Linux import command failed: {cmd}")
             for cmd in setup_commands:
                 exit_code, output = container.exec_run(cmd)
                 if exit_code != 0:
