@@ -6,8 +6,7 @@ import numpy as np
 from apropos.src.bench.craftax.game_dynamics import harness
 from apropos.src.bench.craftax.react import SimpleReActLanguageAgent
 from apropos.src.core.lms.cost import CostMonitor
-# from apropos.src.core.lms.helpers import LLM
-from zyk import LM
+from apropos.src.core.lms.helpers import LLM
 
 
 def hafner_scoring_function_modified(achievements_probs: Dict):
@@ -25,7 +24,7 @@ async def score_rollouts(
     modality: Literal["text", "vision"] = "text",
     mode: Literal["craftax_classic", "craftax_full"] = "craftax_classic",
 ):
-    core_lm = LM(model_name)#LLM(model_name)
+    core_lm = LLM(model_name)
     cost_monitor = CostMonitor(model_name=core_lm.model_name)
     if modality == "text":
         agent = SimpleReActLanguageAgent(
