@@ -1,6 +1,6 @@
 import os
 from datetime import datetime
-from typing import Any, Dict, List, Optional, Type
+from typing import Dict, List, Optional, Type
 
 import loguru
 from pydantic import BaseModel
@@ -147,7 +147,7 @@ class LLM:
         with open(f"{log_dir}/log_{formatted_now}_{i}.txt", "w") as file:
             file.write(log_content)
 
-    def respond_sync(
+    def sync_respond(
         self,
         system_prompt: str,
         user_prompt: str,
@@ -185,7 +185,7 @@ class LLM:
                 max_tokens=self.max_tokens,
             )
 
-    async def respond_async(
+    async def async_respond(
         self,
         system_prompt: str,
         user_prompt: str,
@@ -231,18 +231,24 @@ class LLM:
 if __name__ == "__main__":
     import base64
 
-    lm = LLM("claude-3-haiku-20240307")
-    #lm = LM("claude-3-haiku-20240307")
-    image_path = "apropos/bench/crafter/crafter.png"
+    lm = LLM("gpt-4o-mini")#claude-3-haiku-20240307
+    # image_path = "apropos/bench/crafter/crafter.png"
 
-    def encode_image(image_path) -> Any:
-        with open(image_path, "rb") as image_file:
-            return base64.b64encode(image_file.read()).decode("utf-8")
+    # def encode_image(image_path):
+    #     with open(image_path, "rb") as image_file:
+    #         return base64.b64encode(image_file.read()).decode("utf-8")
 
-    image_bytes = encode_image(image_path)
-    response = lm.respond_sync(
+    # image_bytes = encode_image(image_path)
+    response = lm.sync_respond(
         system_prompt="Hello",
         user_prompt="Hi",
-        images_bytes=[image_bytes],
-    )
+        
+    )#images_bytes=[image_bytes],
     print(response)
+    import asyncio
+    s_response = asyncio.run(lm.async_respond(
+        system_prompt="Hello",
+        user_prompt="Hi", 
+    )#images_bytes=[image_bytes],
+    )
+    print(s_response)
