@@ -2,15 +2,15 @@ import time
 
 import backoff
 from anthropic import Anthropic, APIError, AsyncAnthropic
-from pydantic import BaseModel
 
 from apropos.src.core.lms.cache_init import cache
 from apropos.src.core.lms.vendors.base import BaseProvider
 from apropos.src.core.lms.vendors.json_structured_outputs.core import (
     add_json_instructions_to_messages,
-    extract_pydantic_model_from_respond_async,
-    extract_pydantic_model_from_respond_sync,
+    extract_pydantic_model_from_response_sync,
+    extract_pydantic_model_from_response_async,
 )
+from pydantic import BaseModel
 
 BACKOFF_TOLERANCE = 200
 
@@ -58,7 +58,7 @@ class AnthropicAPIProvider(BaseProvider):
         raw_text_api_response = self.sync_chat_completion(
             messages_with_json_formatting_instructions, model, temperature, max_tokens
         )
-        structured_api_response = extract_pydantic_model_from_respond_sync(
+        structured_api_response = extract_pydantic_model_from_response_sync(
             raw_text_api_response, response_model
         )
         cache.add_to_cache(
@@ -104,7 +104,7 @@ class AnthropicAPIProvider(BaseProvider):
         raw_text_api_response = await self.async_chat_completion(
             messages_with_json_formatting_instructions, model, temperature, max_tokens
         )
-        structured_api_response = await extract_pydantic_model_from_respond_async(
+        structured_api_response = await extract_pydantic_model_from_response_async(
             raw_text_api_response, response_model
         )
         cache.add_to_cache(
