@@ -4,17 +4,16 @@ import os
 from typing import Dict, List
 
 import backoff
-import google.api_core.exceptions
 import google.generativeai as genai
-from google.generativeai.types import HarmBlockThreshold, HarmCategory
-
+from google.generativeai.types import HarmCategory, HarmBlockThreshold
 from apropos.src.core.lms.cache_init import cache
 from apropos.src.core.lms.vendors.base import BaseProvider
 from apropos.src.core.lms.vendors.json_structured_outputs.core import (
     add_json_instructions_to_messages,
-    extract_pydantic_model_from_respond_async,
-    extract_pydantic_model_from_respond_sync,
+    extract_pydantic_model_from_response_sync,
+    extract_pydantic_model_from_response_async,
 )
+import google.api_core.exceptions
 
 # Suppress all logging from google.generativeai
 logging.getLogger("google.generativeai").setLevel(logging.ERROR)
@@ -128,7 +127,7 @@ class DeepmindAPIProvider(BaseProvider):
         raw_text_api_response = await self.async_chat_completion(
             messages_with_json_formatting_instructions, model, temperature, max_tokens
         )
-        structured_api_response = await extract_pydantic_model_from_respond_async(
+        structured_api_response = await extract_pydantic_model_from_response_async(
             raw_text_api_response, response_model
         )
         cache.add_to_cache(
@@ -165,7 +164,7 @@ class DeepmindAPIProvider(BaseProvider):
         raw_text_api_response = self.sync_chat_completion(
             messages_with_json_formatting_instructions, model, temperature, max_tokens
         )
-        structured_api_response = extract_pydantic_model_from_respond_sync(
+        structured_api_response = extract_pydantic_model_from_response_sync(
             raw_text_api_response, response_model
         )
         cache.add_to_cache(
