@@ -1,7 +1,5 @@
-# load_dotenv()
-import ast
 import json
-from typing import Any, Dict, List, Optional, Tuple, Type, get_type_hints
+from typing import Dict, List, Optional, Tuple, Type, Any
 
 import loguru
 
@@ -17,6 +15,10 @@ from apropos.src.core.lms.vendors.json_structured_outputs.healing import (
     json_debugger_sync,
 )
 
+# load_dotenv()
+import ast
+from typing import Dict, get_type_hints
+
 logger = loguru.logger
 
 
@@ -161,7 +163,7 @@ def add_json_instructions_to_messages(
     return messages
 
 
-async def extract_pydantic_model_from_respond_async(
+async def extract_pydantic_model_from_response_async(
     response_raw: str, response_model: Type[BaseModel]
 ) -> BaseModel:
     if "```" in response_raw and "json" in response_raw:
@@ -205,7 +207,7 @@ async def extract_pydantic_model_from_respond_async(
     return final
 
 
-def extract_pydantic_model_from_respond_sync(
+def extract_pydantic_model_from_response_sync(
     response_raw: str, response_model: Type[BaseModel]
 ) -> BaseModel:
     if "```" in response_raw and "json" in response_raw:
