@@ -1,19 +1,18 @@
 import backoff
-import instructor
+from networkx import within_inter_cluster
 import openai
 import pydantic_core
-from networkx import within_inter_cluster
 from openai import AsyncOpenAI, OpenAI
-
 from apropos.src.core.lms.cache_init import cache
+from apropos.src.core.lms.vendors.openai_like import OpenAIStandardProvider
 from apropos.src.core.lms.vendors.json_structured_outputs.core import (
     add_json_instructions_to_messages,
-    extract_pydantic_model_from_respond_async,
-    extract_pydantic_model_from_respond_sync,
+    extract_pydantic_model_from_response_async,
+    extract_pydantic_model_from_response_sync,
 )
-from apropos.src.core.lms.vendors.openai_like import OpenAIStandardProvider
+import instructor
 
-BACKOFF_TOLERANCE = 15  # 20
+BACKOFF_TOLERANCE = 0  # 20
 
 
 class OpenAIAPIProvider(OpenAIStandardProvider):
@@ -66,7 +65,7 @@ class OpenAIAPIProvider(OpenAIStandardProvider):
                     max_tokens,
                 )
                 structured_api_response = (
-                    await extract_pydantic_model_from_respond_async(
+                    await extract_pydantic_model_from_response_async(
                         raw_text_api_response, response_model
                     )
                 )
@@ -110,7 +109,7 @@ class OpenAIAPIProvider(OpenAIStandardProvider):
                     temperature,
                     max_tokens,
                 )
-                structured_api_response = extract_pydantic_model_from_respond_sync(
+                structured_api_response = extract_pydantic_model_from_response_sync(
                     raw_text_api_response, response_model
                 )
                 succeeded = True
