@@ -6,8 +6,7 @@ from typing import Dict, List, Literal, Tuple, Type
 from tqdm import tqdm
 
 from apropos.src.bench.base import Benchmark, Question
-#from apropos.src.core.lms.helpers import LLM
-from zyk import LM
+from apropos.src.core.lms.helpers import LLM
 from apropos.src.core.optimizers.base import DAGOptimizer
 from apropos.src.core.optimizers.miprov2p1.instruction_gen_promtps import (
     InterventionConceptsResponse,
@@ -82,8 +81,7 @@ class MIPrO_V2p1_DAG(DAGOptimizer):
                         [random.choice(failures)] if failures else []
                     ),
                 },
-                #lm=LLM(model_name="gpt-4o-mini"),
-                lm=LM(model_name="gpt-4o-mini"),
+                lm=LLM(model_name="gpt-4o-mini"),
                 response_model=QuestionCurationResponse,
             )
         )
@@ -111,9 +109,9 @@ class MIPrO_V2p1_DAG(DAGOptimizer):
         true_train = self.dataset_handler.train
         self.dataset_handler.train = questions
         if len(questions) > 100:
-            patches = [chr(65 + i) for i in range(len(questions) // 100 + 1)] if len(self.cfg["bootstrapping_patches"]) == 0 else self.cfg["bootstrapping_patches"]
+            patches = [chr(65 + i) for i in range(len(questions) // 100 + 1)]
         else:
-            patches = ["A"] if len(self.cfg["bootstrapping_patches"]) == 0 else self.cfg["bootstrapping_patches"]
+            patches = ["A"]
         demos = await self.bootstrap_demonstrations(n=len(questions), patches=patches)
         self.dataset_handler.train = true_train
         return demos
@@ -288,7 +286,7 @@ class MIPrO_V2p1_DAG(DAGOptimizer):
                         valid_topics_by_subcomponent_by_node
                     ),
                 },
-                lm=LM(model_name="gpt-4o-mini"),
+                lm=LLM(model_name="gpt-4o-mini"),
                 response_model=PromptDeltasResponse,
             )
         )
@@ -324,7 +322,7 @@ class MIPrO_V2p1_DAG(DAGOptimizer):
                 ),
                 "<<<NODE_NAMES>>>": str(list(self.student_program.nodes.keys())),
             },
-            lm=LM(model_name="gpt-4o-mini"),
+            lm=LLM(model_name="gpt-4o-mini"),
             response_model=ProblemsResponse,
         )
         nodes_responsible_by_name = [
@@ -378,7 +376,7 @@ class MIPrO_V2p1_DAG(DAGOptimizer):
                             valid_topics_by_subcomponent_by_node
                         ),
                     },
-                    lm=LM(model_name="gpt-4o-mini"),
+                    lm=LLM(model_name="gpt-4o-mini"),
                     response_model=InterventionConceptsResponse,
                 )
             )
@@ -419,7 +417,7 @@ class MIPrO_V2p1_DAG(DAGOptimizer):
                         ),
                         "<<<FAILURE_DESCRIPTION>>>": problem["problem_description"],
                     },
-                    lm=LM(model_name="gpt-4o-mini", temperature=temperature),
+                    lm=LLM(model_name="gpt-4o-mini", temperature=temperature),
                     response_model=PromptDeltasResponse,
                 )
                 return prompt_delta_response
@@ -493,7 +491,7 @@ class MIPrO_V2p1_DAG(DAGOptimizer):
                             "<<<CURRENT_PROGRAM>>>": program_string,
                             "<<<FAILURE_MODE>>>": problem["problem_description"],
                         },
-                        lm=LM(model_name="gpt-4o-mini"),
+                        lm=LLM(model_name="gpt-4o-mini"),
                         response_model=PromptDeltasVariationsResponse,
                     )
                 )
@@ -612,14 +610,12 @@ class MIPrO_V2p1_DAG(DAGOptimizer):
                 seed=self.cfg["seed"],
                 n_optuna_trials=self.cfg["n_optuna_trials"],
                 questions_for_val=self.dataset_handler.dev[0 : self.cfg["dev_size"]],
-                max_demos_per_node=self.cfg["program"]["max_demos_per_node"],
             )
         elif algorithm == "RandomSearch":
             optimizer = RandomSearch_Optimizer(
                 seed=self.cfg["seed"],
                 n_optuna_trials=self.cfg["n_optuna_trials"],
                 questions_for_val=self.dataset_handler.dev[0 : self.cfg["dev_size"]],
-                max_demos_per_node=self.cfg["max_demos_per_node"],
             )
         return optimizer.search(
             baseline_program=self.student_program,
@@ -673,7 +669,7 @@ class MIPrO_V2p1_DAG(DAGOptimizer):
             demos_by_problem_by_node=demos_by_problem_by_node,
         )
         print("Searching over candidate programs...")
-        best_program, scored_attempts = self.search(algorithm=self.cfg["algorithm"])
+        best_program, scored_attempts = self.search(algorithm="TPE")
         print("... found best program")
         print("All scores: ", [score for score, _, _ in scored_attempts])
         return best_program
\ No newline at end of file
