@@ -3,8 +3,7 @@ from typing import Any, Dict, List
 
 import networkx as nx
 
-#from apropos.src.core.lms.helpers import LLM
-from zyk import LM
+from apropos.src.core.lms.helpers import LLM
 from apropos.src.core.programs.dag import (
     LM_DAG,
     PromptRecord,
@@ -25,16 +24,14 @@ async def llm_transform(
         rm = create_pydantic_model_from_schema(prompt.response_model_scheme)
         outputs_unstructured = await prompt.arun(
             inputs=inputs_normalized,
-            #lm=LLM(llm_config["model_name"], temperature=llm_config["temperature"]),
-            lm=LM(llm_config["model_name"], temperature=llm_config["temperature"]),
+            lm=LLM(llm_config["model_name"], temperature=llm_config["temperature"]),
             custom_instructions_fields={},
             response_model=rm,
         )
     else:
         outputs_unstructured = await prompt.arun(
             inputs=inputs_normalized,
-            #lm=LLM(llm_config["model_name"], temperature=llm_config["temperature"]),
-            lm=LM(llm_config["model_name"], temperature=llm_config["temperature"]),
+            lm=LLM(llm_config["model_name"], temperature=llm_config["temperature"]),
             custom_instructions_fields={},
             response_model=None,
         )
@@ -54,8 +51,7 @@ def llm_transform_sync(
         rm = create_pydantic_model_from_schema(prompt.response_model_scheme)
         outputs_unstructured = prompt.run(
             inputs=inputs_normalized,
-            #llm_config["model_name"], temperature=llm_config["temperature"]),
-            lm=LM(llm_config["model_name"], temperature=llm_config["temperature"]),
+            lm=LLM(llm_config["model_name"], temperature=llm_config["temperature"]),
             custom_instructions_fields={},
             response_model=rm,
             multi_threaded=llm_config["multi_threaded"]
@@ -65,8 +61,7 @@ def llm_transform_sync(
     else:
         outputs_unstructured = prompt.run(
             inputs=inputs_normalized,
-            #lm=LLM(llm_config["model_name"], temperature=llm_config["temperature"]),
-            lm=LM(llm_config["model_name"], temperature=llm_config["temperature"]),
+            lm=LLM(llm_config["model_name"], temperature=llm_config["temperature"]),
             custom_instructions_fields={},
             response_model=None,
             multi_threaded=llm_config["multi_threaded"]
