@@ -2,8 +2,7 @@ from typing import Any, Dict, List, Literal, Optional, Union
 
 from pydantic import BaseModel
 
-#from apropos.src.core.lms.helpers import LLM
-from zyk import LM
+from apropos.src.core.lms.helpers import LLM
 
 
 class Topic(BaseModel):
@@ -144,6 +143,7 @@ class PromptTemplate(BaseModel):
                         f"{field}", topic.instructions_fields[field]
                     )
             system += template + "\n\n"
+        # system+="\n\nObjective:\n\n"
         for topic in self.system.objective:
             template = topic.topic_template
             for field in topic.input_fields:
@@ -186,32 +186,13 @@ class PromptTemplate(BaseModel):
                     )
             system += template + "\n\n"
         if len(self.demonstrations) > 0:
-            system += "\n\nDemonstrations of Successful Responses:\n\n"
-            for i, demo in enumerate(self.demonstrations):
-                demo_snippet = f"\n<demonstration_{i}>"
-                demo_snippet += f"\n<input>"
-                for input_field, value in demo.inputs.items():
-                    input_field = input_field.replace("<<<", "").replace(">>>", "")
-                    input_field = input_field.replace("_", " ").lower()
-                    demo_snippet += f"\n<{input_field}>{value}</{input_field}>"
-                demo_snippet += f"\n</input>"
-               
-                if isinstance(demo.outputs, dict):
-                    demo_snippet += f"\n<valid_output>"
-                    for output_field, value in demo.outputs.items():
-                        output_field = output_field.replace("<<<", "").replace(">>>", "")
-                        output_field = output_field.replace("_", " ").lower()
-                        demo_snippet += f"\n<{output_field}>{value}</{output_field}>"
-                    demo_snippet += f"\n</valid_output>"
-                else:
-                    demo_snippet += f"\n<valid_output>{demo.outputs}</valid_output>"
-                if demo.annotation:
-                    demo_snippet += f"\n<annotation>"
-                    demo_snippet += f"\n{demo.annotation}"
-                    demo_snippet += f"\n</annotation>"
-                demo_snippet += f"\n</demonstration_{i}>"
-                system += demo_snippet
-        
+            system += "\n\n Demonstrations of Success:\n\n"
+            for demo in self.demonstrations:
+                annotation_snippet = (
+                    f"Annotation: {demo.annotation}\n" if demo.annotation else ""
+                )
+                system += f"Input: {demo.inputs}\nOutput: {demo.outputs}\n{annotation_snippet}\n"
+
         user = ""
         for topic in self.user.user:
             template = topic.topic_template
@@ -244,21 +225,21 @@ class PromptTemplate(BaseModel):
     def run(
         self,
         inputs: Dict[str, str],
-        lm: LM,
+        lm: LLM,
         custom_instructions_fields: Dict[str, str] = {},
         response_model: Optional[Any] = None,
         multi_threaded: bool = False,
     ):
         system, user = self.compile(inputs, custom_instructions_fields)
         if response_model:
-            response = lm.respond_sync(
+            response = lm.sync_respond(
                 system_prompt=system,
                 user_prompt=user,
                 response_model=response_model,
                 multi_threaded=multi_threaded,
             )
         else:
-            response = lm.respond_sync(
+            response = lm.sync_respond(
                 system_prompt=system, user_prompt=user, multi_threaded=multi_threaded
             )
         return response
@@ -266,17 +247,17 @@ class PromptTemplate(BaseModel):
     async def arun(
         self,
         inputs: Dict[str, str],
-        lm: LM,
+        lm: LLM,
         custom_instructions_fields: Dict[str, str] = {},
         response_model: Optional[Any] = None,
     ):
         system, user = self.compile(inputs, custom_instructions_fields)
         if response_model:
-            response = await lm.respond_async(
+            response = await lm.async_respond(
                 system_prompt=system, user_prompt=user, response_model=response_model
             )
         else:
-            response = await lm.respond_async(system_prompt=system, user_prompt=user)
+            response = await lm.async_respond(system_prompt=system, user_prompt=user)
         assert isinstance(response, str) or isinstance(
             response, BaseModel
         ), f"Response: {response}"
