@@ -1,7 +1,7 @@
 import asyncio
 
 from apropos.src.bench.base import Benchmark
-from apropos.src.bench.hendryks_math.dags.plan_act import (
+from apropos.src.bench.hendryks_math.dags.plan_execute import (
     hendryks_math_plan_execute_example,
 )
 from apropos.src.bench.hendryks_math.dags.single_step import (
