@@ -1,5 +1,4 @@
-#from apropos.src.core.lms.helpers import LLM
-from zyk import LM
+from apropos.src.core.lms.helpers import LLM
 import numpy as np
 from apropos.src.core.utils.program_grounding import (
     Metric,
@@ -89,12 +88,10 @@ if __name__ == "__main__":
         get_hendryks_messages_and_gold_outputs()
     )
 
-    # grounding_llm = LLM(
-    #     "claude-3-5-sonnet-20240620"
-    # )  # For structuring prompts, better to have high-power
-    # program_llm = LLM("gpt-4o-mini")  # For generating programs
-    grounding_llm = LM("claude-3-5-sonnet-20240620")
-    program_llm = LM("gpt-4o-mini")
+    grounding_llm = LLM(
+        "claude-3-5-sonnet-20240620"
+    )  # For structuring prompts, better to have high-power
+    program_llm = LLM("gpt-4o-mini")  # For generating programs
     metric = Metric(
         gold_outputs_for_dataset=gold_outputs, metric_function=custom_math_metric
     )
