@@ -1,4 +1,4 @@
-from apropos.src.bench.hendryks_math.dags.plan_act import (
+from apropos.src.bench.hendryks_math.dags.plan_execute import (
     hendryks_math_plan_execute_example,
 )
 from apropos.src.bench.hendryks_math.main import HendryksMath_Benchmark
